@@ -7,7 +7,7 @@ RDF::Trine::Error - Error classes for RDF::Trine.
 
 =head1 VERSION
 
-This document describes RDF::Trine::Error version 0.108
+This document describes RDF::Trine::Error version 0.110
 
 =head1 SYNOPSIS
 
@@ -35,10 +35,9 @@ use base qw(Error);
 
 ######################################################################
 
-our ($VERSION, $debug);
+our ($VERSION);
 BEGIN {
-	$debug		= 0;
-	$VERSION	= 0.108;
+	$VERSION	= '0.110';
 }
 
 ######################################################################
@@ -59,6 +58,10 @@ package RDF::Trine::Error::SerializationError;
 
 use base qw(RDF::Trine::Error);
 
+package RDF::Trine::Error::DatabaseError;
+
+use base qw(RDF::Trine::Error);
+
 
 1;
 
