@@ -7,7 +7,7 @@ RDF::Trine::Iterator - Stream (iterator) class for SPARQL query results.
 
 =head1 VERSION
 
-This document describes RDF::Trine::Iterator version 0.107.
+This document describes RDF::Trine::Iterator version 0.110.
 
 
 =head1 SYNOPSIS
@@ -33,6 +33,7 @@ no warnings 'redefine';
 
 use JSON;
 use Data::Dumper;
+use Log::Log4perl;
 use Carp qw(carp);
 use Scalar::Util qw(blessed reftype refaddr);
 
@@ -40,15 +41,13 @@ use XML::SAX;
 use RDF::Trine::Node;
 use RDF::Trine::Iterator::SAXHandler;
 
-our ($VERSION, $debug, @ISA, @EXPORT_OK);
-use constant DEBUG	=> 0;
+our ($VERSION, @ISA, @EXPORT_OK);
 BEGIN {
-	$debug		= DEBUG;
-	$VERSION	= 0.107;
+	$VERSION	= '0.110';
 	
 	require Exporter;
 	@ISA		= qw(Exporter);
-	@EXPORT_OK	= qw(sgrep smap swatch);
+	@EXPORT_OK	= qw(sgrep smap swatch sfinally);
 	use overload 'bool' => sub { $_[0] };
 	use overload '&{}' => sub {
 		my $self	= shift;
@@ -83,7 +82,7 @@ sub new {
 	my $names		= shift || [];
 	my %args		= @_;
 	
-	if (ref($stream) and reftype($stream) eq 'ARRAY') {
+	if (ref($stream) and ref($stream) eq 'ARRAY') {
 		my $array	= $stream;
 		$stream	= sub {
 			return shift(@$array);
@@ -102,6 +101,7 @@ sub new {
 		_stream		=> $stream,
 		_args		=> \%args,
 		_row		=> undef,
+		_peek		=> [],
 #		_source		=> Carp::longmess(),
 	};
 	
@@ -185,73 +185,6 @@ sub from_string {
 	return $iter;
 }
 
-=item C<< from_handle_incremental ( $socket, $chunk_size ) >>
-
-Returns a new iterator using the XML content read from C<< $socket >>.
-This call will block until the entire <head/> element is read from the socket,
-with results being read incrementally as the C<< next >> method is called.
-
-=cut
-
-sub from_handle_incremental {
-	my $class		= shift;
-	my $handle		= shift;
-	my $chunk_size	= shift || 1024;
-	
-	eval "
-		require XML::SAX::Expat;
-		require XML::SAX::Expat::Incremental;
-	";
-	if ($@) {
-		die $@;
-	}
-	local($XML::SAX::ParserPackage)	= 'XML::SAX::Expat::Incremental';
-	my $handler	= RDF::Trine::Iterator::SAXHandler->new();
-	my $p	= XML::SAX::Expat::Incremental->new( Handler => $handler );
-	$p->parse_start;
-	
-	until ($handler->has_head) {
-		my $buffer;
-		$handle->recv($buffer, $chunk_size);
-		if (my $size = length($buffer)) {
-			warn "read $size bytes\n" if ($debug);
-			$p->parse_more( $buffer );
-		} else {
-			warn "read 0 bytes\n" if ($debug);
-			if ($handle->eof) {
-				warn "-> handle is at eof\n" if ($debug);
-				return undef;
-			}
-			select( undef, undef, undef, 0.25 );
-		}
-	}
-	
-	warn "iterator has head. now returning an iterative stream." if ($debug);
-	
-	my @args	= $handler->iterator_args;
-	my $iter	= sub {
-		my $data;
-		while (not($handler->has_end) and not($data = $handler->pull_result)) {
-			my $buffer;
-			$handle->recv($buffer, $chunk_size);
-			if (my $size = length($buffer)) {
-				warn "read $size bytes\n" if ($debug);
-				$p->parse_more( $buffer );
-			} else {
-				warn "read 0 bytes\n" if ($debug);
-				if ($handle->eof) {
-					warn "-> handle is at eof\n" if ($debug);
-					return undef;
-				}
-				select( undef, undef, undef, 0.25 );
-			}
-		}
-		return $data;
-	};
-	return $handler->iterator_class->new( $iter, @args );
-	
-}
-
 
 =item C<< next >>
 
@@ -266,6 +199,10 @@ sub next {
 	my $self	= shift;
 	return if ($self->{_finished});
 	
+	if (scalar(@{ $self->{_peek} })) {
+		return shift(@{ $self->{_peek} });
+	}
+	
 	my $stream	= $self->{_stream};
 	my $value	= $stream->();
 	unless (defined($value)) {
@@ -277,6 +214,21 @@ sub next {
 	return $value;
 }
 
+=item C<< peek >>
+
+Returns the next value from the iterator without consuming it. The value will
+remain in queue until the next call to C<< next >>.
+
+=cut
+
+sub peek {
+	my $self	= shift;
+	return if ($self->{_finished});
+	
+	my $value	= $self->next;
+	push( @{ $self->{_peek} }, $value );
+	return $value;
+}
 
 =item C<< current >>
 
@@ -476,25 +428,6 @@ sub _row {
 	return $self->{_row};
 }
 
-# =item C<< bridge >>
-# 
-# Returns the model bridge object used for insepcting the objects returned by the stream.
-# 
-# =cut
-# 
-# sub bridge {
-# 	my $self	= shift;
-# 	if (@_) {
-# 		$self->_args->{bridge}	= shift;
-# 	}
-# 	return $self->_args->{bridge};
-# }
-# 
-# sub _bridge {
-# 	my $self	= shift;
-# 	return $self->bridge;
-# }
-
 sub _names {
 	my $self	= shift;
 	return $self->{_names};
@@ -523,6 +456,7 @@ sub add_extra_result_data {
 
 sub extra_result_data {
 	my $self	= shift;
+	$self->peek;
 	my $args	= $self->_args;
 	my $extra	= $args->{ extra_result_data };
 	return $extra;
@@ -650,6 +584,37 @@ sub swatch (&$) {
 	return $s;
 }
 
+=item C<sfinally { EXPR } $stream>
+
+=cut
+
+sub sfinally (&$) {
+	my $block	= shift;
+	my $stream	= shift;
+	my @args	= $stream->construct_args();
+	my $class	= ref($stream);
+	
+	my $open	= 1;
+	my $next	= sub {
+		return undef unless ($open);
+		if (@_ and $_[0]) {
+			$block->();
+			$stream->close;
+			$open	= 0;
+		}
+		my $data	= $stream->next;
+		unless ($data) {
+			$block->();
+			$open	= 0;
+			return undef;
+		}
+		return $data;
+	};
+	
+	my $s		= $stream->_new( $next, @args );
+	return $s;
+}
+
 1;
 
 __END__
@@ -666,7 +631,7 @@ L<XML::SAX|XML::SAX>
 
 =head1 AUTHOR
 
-Gregory Todd Williams  C<< <greg@evilfunhouse.com> >>
+Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 
 =head1 LICENCE AND COPYRIGHT
