@@ -23,12 +23,15 @@ RDF::Trine::Iterator::Bindings - Stream (iterator) class for bindings query resu
 
 package RDF::Trine::Iterator::Bindings;
 
+use utf8;
 use strict;
 use warnings;
 no warnings 'redefine';
 use Data::Dumper;
 
 use JSON 2.0;
+use Text::Table;
+use Log::Log4perl;
 use Scalar::Util qw(reftype);
 use List::MoreUtils qw(uniq);
 use RDF::Trine::Iterator::Bindings::Materialized;
@@ -36,10 +39,9 @@ use RDF::Trine::Iterator::Bindings::Materialized;
 use RDF::Trine::Iterator qw(smap);
 use base qw(RDF::Trine::Iterator);
 
-our ($VERSION, $debug);
+our ($VERSION);
 BEGIN {
-	$debug		= 0;
-	$VERSION	= 0.107;
+	$VERSION	= '0.110';
 }
 
 =item C<new ( \@results, \@names, %args )>
@@ -134,10 +136,9 @@ sub join_streams {
 # 	my $bridge	= shift;
 	my %args	= @_;
 	
-#	my $debug	= $args{debug};
-	
 	Carp::confess unless ($a->isa('RDF::Trine::Iterator::Bindings'));
 	Carp::confess unless ($b->isa('RDF::Trine::Iterator::Bindings'));
+	my $l		= Log::Log4perl->get_logger("rdf.trine.iterator.bindings");
 	
 	my @join_sorted_by;
 	if (my $o = $args{ orderby }) {
@@ -145,25 +146,25 @@ sub join_streams {
 		my $a_sort		= join(',', $a->sorted_by);
 		my $b_sort		= join(',', $b->sorted_by);
 		
-		if ($debug) {
-			warn '---------------------------';
-			warn 'REQUESTED SORT in JOIN: ' . Dumper($req_sort);
-			warn 'JOIN STREAM SORTED BY: ' . Dumper($a_sort);
-			warn 'JOIN STREAM SORTED BY: ' . Dumper($b_sort);
+		if ($l->is_debug) {
+			$l->debug('---------------------------');
+			$l->debug('REQUESTED SORT in JOIN: ' . Dumper($req_sort));
+			$l->debug('JOIN STREAM SORTED BY: ' . Dumper($a_sort));
+			$l->debug('JOIN STREAM SORTED BY: ' . Dumper($b_sort));
 		}
 		my $actual_sort;
 		if (substr( $a_sort, 0, length($req_sort) ) eq $req_sort) {
-			warn "first stream is already sorted. using it in the outer loop.\n" if ($debug);
+			$l->debug("first stream is already sorted. using it in the outer loop.");
 		} elsif (substr( $b_sort, 0, length($req_sort) ) eq $req_sort) {
-			warn "second stream is already sorted. using it in the outer loop.\n" if ($debug);
+			$l->debug("second stream is already sorted. using it in the outer loop.");
 			($a,$b)	= ($b,$a);
 		} else {
 			my $a_common	= join('!', $a_sort, $req_sort);
 			my $b_common	= join('!', $b_sort, $req_sort);
 			if ($a_common =~ qr[^([^!]+)[^!]*!\1]) {	# shared prefix between $a_sort and $req_sort?
-				warn "first stream is closely sorted ($1).\n" if ($debug);
+				$l->debug("first stream is closely sorted ($1).");
 			} elsif ($b_common =~ qr[^([^!]+)[^!]*!\1]) {	# shared prefix between $b_sort and $req_sort?
-				warn "second stream is closely sorted ($1).\n" if ($debug);
+				$l->debug("second stream is closely sorted ($1).");
 				($a,$b)	= ($b,$a);
 			}
 		}
@@ -171,7 +172,7 @@ sub join_streams {
 	}
 	
 	my $stream	= $self->nested_loop_join( $a, $b, %args );
-	warn "JOINED stream is sorted by: " . join(',', @join_sorted_by) . "\n" if ($debug);
+	$l->debug("JOINED stream is sorted by: " . join(',', @join_sorted_by));
 	$stream->{sorted_by}	= \@join_sorted_by;
 	return $stream;
 }
@@ -200,10 +201,9 @@ sub nested_loop_join {
 #	my $bridge	= shift;
 	my %args	= @_;
 	
-#	my $debug	= $args{debug};
-	
 	Carp::confess unless ($astream->isa('RDF::Trine::Iterator::Bindings'));
 	Carp::confess unless ($bstream->isa('RDF::Trine::Iterator::Bindings'));
+	my $l		= Log::Log4perl->get_logger("rdf.trine.iterator.bindings");
 	
 	################################################
 	### BNODE MAP STUFF
@@ -240,17 +240,17 @@ sub nested_loop_join {
 	my $sub	= sub {
 		OUTER: while (1) {
 			if ($need_new_a) {
-				warn "### fetching new outer tuple" if ($debug);
+				$l->debug("### fetching new outer tuple");
 				$rowa = $a->next;
 				$inner_index	= 0;
 				$need_new_a		= 0;
 			}
-			warn "OUTER: " . Dumper($rowa) if ($debug);
+			$l->debug("OUTER: " . Dumper($rowa));
 			return undef unless ($rowa);
 			LOOP: while ($inner_index <= $#data) {
 				my $rowb	= $data[ $inner_index++ ];
-				warn "- INNER[ $inner_index ]: " . Dumper($rowb) if ($debug);
-				warn "[--JOIN--] " . join(' ', map { my $row = $_; '{' . join(', ', map { join('=', $_, ($row->{$_}) ? $row->{$_}->as_string : '(undef)') } (keys %$row)) . '}' } ($rowa, $rowb)) . "\n" if ($debug);
+				$l->debug("- INNER[ $inner_index ]: " . Dumper($rowb));
+				$l->debug("[--JOIN--] " . join(' ', map { my $row = $_; '{' . join(', ', map { join('=', $_, ($row->{$_}) ? $row->{$_}->as_string : '(undef)') } (keys %$row)) . '}' } ($rowa, $rowb)));
 				my %keysa	= map {$_=>1} (keys %$rowa);
 				my @shared	= grep { $keysa{ $_ } } (keys %$rowb);
 				foreach my $key (@shared) {
@@ -285,22 +285,24 @@ sub nested_loop_join {
 									}
 								}
 							} else {
-								Carp::cluck "no query,bridge in args" if ($debug);
+								if ($l->is_debug) {
+									$l->logcluck("no query,bridge in args");
+								}
 							}
 						}
 						
 						unless ($equal) {
-							warn "can't join because mismatch of $key (" . join(' <==> ', map {$_->as_string} ($val_a, $val_b)) . ")" if ($debug);
+							$l->debug("can't join because mismatch of $key (" . join(' <==> ', map {$_->as_string} ($val_a, $val_b)) . ")");
 							next LOOP;
 						}
 					}
 				}
 				
 				my $row	= { (map { $_ => $rowa->{$_} } grep { defined($rowa->{$_}) } keys %$rowa), (map { $_ => $rowb->{$_} } grep { defined($rowb->{$_}) } keys %$rowb) };
-				if ($debug) {
-					warn "JOINED:\n";
+				if ($l->is_debug) {
+					$l->debug("JOINED:");
 					foreach my $key (keys %$row) {
-						warn "$key\t=> " . $row->{ $key }->as_string . "\n";
+						$l->debug("$key\t=> " . $row->{ $key }->as_string);
 					}
 				}
 				return $row;
@@ -314,21 +316,6 @@ sub nested_loop_join {
 }
 
 
-=item C<< next_result >>
-
-Returns the next binding result.
-
-=cut
-
-sub next_result {
-	my $self	= shift;
-	my $data	= $self->SUPER::next_result();
-	if (defined($data)) {
-		Carp::confess "not a HASH ref" unless (reftype($data) eq 'HASH');
-	}
-	return $data;
-}
-
 =item C<< sorted_by >>
 
 =cut
@@ -418,10 +405,8 @@ Returns the number of variable bindings in the current result.
 sub bindings_count {
 	my $self	= shift;
 	my $names	= $self->{_names};
-	my $row		= ($self->open) ? $self->current : $self->next;
 	return scalar( @$names ) if (scalar(@$names));
-	return 0 unless ref($row);
-	return scalar( @{ [ keys %$row ] } );
+	return 0;
 }
 
 =item C<is_bindings>
@@ -489,8 +474,69 @@ Returns an XML serialization of the stream data.
 sub as_xml {
 	my $self			= shift;
 	my $max_result_size	= shift || 0;
+	my $string	= '';
+	open( my $fh, '>', \$string );
+	$self->print_xml( $fh, $max_result_size );
+	close($fh);
+	return $string;
+}
+
+=item C<as_string ( $max_size )>
+
+Returns a string table serialization of the stream data.
+
+=cut
+
+sub as_string {
+	my $self			= shift;
+	my $max_result_size	= shift || 0;
+	my @names			= $self->binding_names;
+	my $headers			= \@names;
+	my $rows			= [ map { [ @{$_}{ @names } ] } $self->get_all ];
+
+	my @rule			= qw(- +);
+	my @headers			= (\q"| ");
+	push(@headers, map { $_ => \q" | " } @$headers);
+	pop	@headers;
+	push @headers => (\q" |");
+	
+	unless ('ARRAY' eq ref $rows) {
+		die("make_table() rows must be an AoA with rows being same size as headers");
+	}
+	
+	if ('ARRAY' eq ref $rows->[0]) {
+		if (@$headers == @{ $rows->[0] }) {
+			my $table = Text::Table->new(@headers);
+			$table->rule(@rule);
+			$table->body_rule(@rule);
+			$table->load(@$rows);
+		
+			return join('',
+					$table->rule(@rule),
+					$table->title,
+					$table->rule(@rule),
+					map({ $table->body($_) } 0 .. @$rows),
+					$table->rule(@rule)
+				);
+		} else {
+			die("make_table() rows must be an AoA with rows being same size as headers");
+		}
+	} else {
+		return '';
+	}
+}
+
+=item C<< print_xml ( $fh, $max_size ) >>
+
+Prints an XML serialization of the stream data to the filehandle $fh.
+
+=cut
+
+sub print_xml {
+	my $self			= shift;
+	my $fh				= shift;
+	my $max_result_size	= shift || 0;
 	my $width			= $self->bindings_count;
-# 	my $bridge			= $self->bridge;
 	
 	my @variables;
 	for (my $i=0; $i < $width; $i++) {
@@ -498,24 +544,47 @@ sub as_xml {
 		push(@variables, $name) if $name;
 	}
 	
+	no strict 'refs';
+	print {$fh} <<"END";
+<?xml version="1.0"?>
+<sparql xmlns="http://www.w3.org/2005/sparql-results#">
+<head>
+END
+	
+	my $t	= join("\n", map { qq(\t<variable name="$_"/>) } @variables);
+	
+	my $delay_output	= 0;
+	my $delayed			= '';
+	
+	if ($self->extra_result_data) {
+		$delay_output	= $fh;
+		undef $fh;
+		open( $fh, '>', \$delayed ) or die $!;
+	} else {
+		print {$fh} "${t}\n";
+	}
+	
+	print {$fh} <<"END";
+</head>
+<results>
+END
+	
 	my $count	= 0;
-	my $t	= join("\n\t", map { qq(<variable name="$_"/>) } @variables);
-	my $head	= $t;
-	my $results	= '';
-	while (!$self->finished) {
+	while (my $row = $self->next) {
 		my @row;
-		$results	.= "\t\t<result>\n";
+		print {$fh} "\t\t<result>\n";
 		for (my $i = 0; $i < $width; $i++) {
 			my $name	= $self->binding_name($i);
-			my $value	= $self->binding_value($i);
-			$results	.= "\t\t\t" . $self->format_node_xml($value, $name) . "\n";
+			my $value	= $row->{ $name };
+			print {$fh} "\t\t\t" . $self->format_node_xml($value, $name) . "\n";
 		}
-		$results	.= "\t\t</result>\n";
+		print {$fh} "\t\t</result>\n";
 		
 		last if ($max_result_size and ++$count >= $max_result_size);
-	} continue { $self->next_result }
+	}
 	
-	if (my $extra = $self->extra_result_data) {
+	if ($delay_output) {
+		my $extra = $self->extra_result_data;
 		my $extraxml	= '';
 		foreach my $tag (keys %$extra) {
 			$extraxml	.= qq[<extra name="${tag}">\n];
@@ -542,20 +611,15 @@ sub as_xml {
 		$uri	=~ s/</&lt;/g;
 		$uri	=~ s/'/&apos;/g;
 		$uri	=~ s/"/&quot;/g;
-		$head	.= qq[\n\t<link href="$uri" />\n];
+		
+		$fh		= $delay_output;
+		print {$fh} "${t}\n";
+		print {$fh} qq[\t<link href="$uri" />\n];
+		print {$fh} $delayed;
 	}
 	
-	my $xml	= <<"END";
-<?xml version="1.0"?>
-<sparql xmlns="http://www.w3.org/2005/sparql-results#">
-<head>
-	${head}
-</head>
-<results>
-${results}</results>
-</sparql>
-END
-	return $xml;
+	print {$fh} "</results>\n";
+	print {$fh} "</sparql>\n";
 }
 
 =begin private
@@ -624,7 +688,7 @@ L<Scalar::Util|Scalar::Util>
 
 =head1 AUTHOR
 
-Gregory Todd Williams  C<< <greg@evilfunhouse.com> >>
+Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 
 =head1 LICENCE AND COPYRIGHT
