@@ -43,11 +43,9 @@ use base qw(RDF::Trine::Iterator::Bindings);
 use Data::Dumper;
 use Scalar::Util qw(blessed reftype);
 
-our ($VERSION, $debug);
-use constant DEBUG	=> 0;
+our ($VERSION);
 BEGIN {
-	$debug		= DEBUG;
-	$VERSION	= 0.106;
+	$VERSION	= '0.110';
 }
 
 =item C<< new ( \@results, \@names, %args ) >>
@@ -135,7 +133,7 @@ __END__
 
 =head1 AUTHOR
 
-Gregory Todd Williams  C<< <greg@evilfunhouse.com> >>
+Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 
 =head1 LICENCE AND COPYRIGHT
