@@ -28,11 +28,9 @@ no warnings 'redefine';
 use JSON 2.0;
 
 use base qw(RDF::Trine::Iterator);
-our ($VERSION, $debug);
-use constant DEBUG	=> 0;
+our ($VERSION);
 BEGIN {
-	$debug		= DEBUG;
-	$VERSION	= 0.107;
+	$VERSION	= '0.110';
 }
 
 =item C<new ( \@results, %args )>
@@ -84,7 +82,7 @@ Returns an XML serialization of the stream data.
 =cut
 
 sub as_xml {
-	my $self			= shift;
+	my $self	= shift;
 	my $value	= $self->get_boolean ? 'true' : 'false';
 	my $xml	= <<"END";
 <?xml version="1.0"?>
@@ -98,6 +96,19 @@ END
 	return $xml;
 }
 
+=item C<< print_xml ( $fh, $max_size ) >>
+
+Prints an XML serialization of the stream data to the filehandle $fh.
+
+=cut
+
+sub print_xml {
+	my $self	= shift;
+	my $fh		= shift;
+	no strict 'refs';
+	print {$fh} $self->as_xml;
+}
+
 =item C<as_json ( $max_size )>
 
 Returns a JSON serialization of the stream data.
@@ -142,7 +153,7 @@ L<Scalar::Util|Scalar::Util>
 
 =head1 AUTHOR
 
-Gregory Todd Williams  C<< <greg@evilfunhouse.com> >>
+Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 
 =head1 LICENCE AND COPYRIGHT
