@@ -21,10 +21,11 @@ use Carp qw(carp croak confess);
 
 ######################################################################
 
-our ($VERSION, $debug);
+our ($VERSION, $USE_XMLLITERALS);
 BEGIN {
-	$debug		= 0;
-	$VERSION	= 0.107;
+	$VERSION	= '0.110';
+	eval "use RDF::Trine::Node::Literal::XML;";
+	$USE_XMLLITERALS	= (RDF::Trine::Node::Literal::XML->can('new')) ? 1 : 0;
 }
 
 ######################################################################
@@ -46,6 +47,19 @@ sub new {
 	my $literal	= shift;
 	my $lang	= shift;
 	my $dt		= shift;
+	
+	if ($USE_XMLLITERALS and defined($dt) and $dt eq 'http://www.w3.org/1999/02/22-rdf-syntax-ns#XMLLiteral') {
+		return RDF::Trine::Node::Literal::XML->new( $literal, $lang, $dt );
+	} else {
+		return $class->_new( $literal, $lang, $dt );
+	}
+}
+
+sub _new {
+	my $class	= shift;
+	my $literal	= shift;
+	my $lang	= shift;
+	my $dt		= shift;
 	my $self;
 
 	if ($lang and $dt) {
@@ -109,6 +123,10 @@ sub sse {
 	my $self	= shift;
 	my $literal	= $self->literal_value;
 	$literal	=~ s/\\/\\\\/g;
+	
+	my $escaped	= $self->_unicode_escape( $literal );
+	$literal	= $escaped;
+	
 	$literal	=~ s/"/\\"/g;
 	$literal	=~ s/\n/\\n/g;
 	$literal	=~ s/\t/\\t/g;
@@ -181,8 +199,7 @@ Returns true if the two nodes are equal, false otherwise.
 sub equal {
 	my $self	= shift;
 	my $node	= shift;
-	return 0 unless (blessed($node) and $node->isa('RDF::Trine::Node'));
-	return 0 unless ($self->type eq $node->type);
+	return 0 unless (blessed($node) and $node->isa('RDF::Trine::Node::Literal'));
 	return 0 unless ($self->literal_value eq $node->literal_value);
 	if ($self->literal_datatype or $node->literal_datatype) {
 		no warnings 'uninitialized';
