@@ -12,9 +12,9 @@ package RDF::Trine::Statement;
 use strict;
 use warnings;
 no warnings 'redefine';
-use constant DEBUG	=> 0;
 
 use Data::Dumper;
+use Log::Log4perl;
 use List::MoreUtils qw(uniq);
 use Carp qw(carp croak confess);
 use Scalar::Util qw(blessed reftype);
@@ -22,10 +22,9 @@ use RDF::Trine::Iterator qw(smap sgrep swatch);
 
 ######################################################################
 
-our ($VERSION, $debug);
+our ($VERSION);
 BEGIN {
-	$debug		= 0;
-	$VERSION	= 0.107;
+	$VERSION	= '0.110';
 }
 
 ######################################################################
@@ -152,6 +151,34 @@ sub sse {
 	);
 }
 
+=item C<< from_sse ( $string, $context ) >>
+
+Parses the supplied SSE-encoded string and returns a RDF::Trine::Statement object.
+
+=cut
+
+sub from_sse {
+	my $class	= shift;
+	my $context	= $_[1];
+	for ($_[0]) {
+		if (m/^[(]triple/) {
+			s/^[(]triple\s+//;
+			my @nodes;
+			push(@nodes, RDF::Trine::Node->from_sse( $_, $context ));
+			push(@nodes, RDF::Trine::Node->from_sse( $_, $context ));
+			push(@nodes, RDF::Trine::Node->from_sse( $_, $context ));
+			if (m/^\s*[)]/) {
+				s/^\s*[)]//;
+				return RDF::Trine::Statement->new( @nodes );
+			} else {
+				throw RDF::Trine::Error -text => "Cannot parse end-of-triple from SSE string: >>$_<<";
+			}
+		} else {
+			throw RDF::Trine::Error -text => "Cannot parse triple from SSE string: >>$_<<";
+		}
+	}
+}
+
 =item C<< type >>
 
 Returns the type of this algebra expression.
@@ -231,14 +258,15 @@ sub subsumes {
 	my @match	= $st->nodes;
 	
 	my %bind;
+	my $l		= Log::Log4perl->get_logger("rdf.trine.statement");
 	foreach my $i (0..2) {
 		my $m	= $match[ $i ];
 		if ($nodes[$i]->isa('RDF::Trine::Node::Variable')) {
 			my $name	= $nodes[$i]->name;
 			if (exists( $bind{ $name } )) {
-				warn "variable $name has already been bound" if ($debug);
+				$l->debug("variable $name has already been bound");
 				if (not $bind{ $name }->equal( $m )) {
-					warn "-> and " . $bind{$name}->sse . " does not equal " . $m->sse if ($debug);
+					$l->debug("-> and " . $bind{$name}->sse . " does not equal " . $m->sse);
 					return 0;
 				}
 			} else {
